--[[
##############################################################################
Inked Shadow Vaults  By: keivamp
##############################################################################
]]--
--[[ GLOBALS ]]--
local _G = _G;
local unpack  = _G.unpack;
local select  = _G.select;
local ipairs  = _G.ipairs;
local pairs   = _G.pairs;
--[[ ADDON ]]--
local SV = _G['InkedSV'];
local L = SV.L;
local MOD = SV.Skins;
local Schema = MOD.Schema;

local MAX_NUM_ITEMS = _G.MAX_NUM_ITEMS
--[[
##########################################################
HELPERS
##########################################################
]]--
local QuestLogFrameList = {
	"QuestLogFramePopupDetailFrame",
	"QuestLogPopupDetailFrameAbandonButton",
	"QuestLogPopupDetailFrameShareButton",
	"QuestLogPopupDetailFrameTrackButton",
	"QuestLogPopupDetailFrameCancelButton",
	"QuestLogPopupDetailFrameCompleteButton",
	"QuestLogFrameAbandonButton",
	"QuestFrameExitButton",
	"QuestRewardScrollFrame",
	"QuestFrameRewardPanel",
	"QuestFrameProgressPanel",	
	"QuestLogDetailScrollFrame",
	"QuestDetailScrollFrame",
	"QuestFrameDetailPanel",
	"QuestGreetingScrollFrame",
	"QuestFrameGreetingPanel",
	"QuestGreetingScrollChildFrame"
};

local function QuestScrollHelper(b, c, d, e)
	-- SV.API:Set("Frame", b, "Inset")
	b.spellTex = b:CreateTexture(nil, 'ARTWORK')
	b.spellTex:SetTexture([[Interface\QuestLogFrame\QuestBG]])
	if e then
		 b.spellTex:SetPoint("TOPLEFT", 2, -2)
	else
		 b.spellTex:SetPoint("TOPLEFT")
	end
	b.spellTex:SetSize(c or 506, d or 615)
	b.spellTex:SetTexCoord(0, 1, 0.02, 1)
end

local QuestRewardScrollFrame_OnShow = function(self)
	if(not self.Panel) then
		SV.API:Set("Frame", self)
		QuestScrollHelper(self, 509, 630, false)
		self:SetHeight(self:GetHeight() - 2)
	end
	if(self.spellTex) then
		self.spellTex:SetHeight(self:GetHeight() + 217)
	end
end

local function StyleQuestRewards()
	local rewardsFrame = QuestInfoFrame.rewardsFrame
	if(not rewardsFrame) then return end
	local parentName = rewardsFrame:GetName()
	for i = 1, 10 do
		local name = ("%sQuestInfoItem%d"):format(parentName,i)
		SV.API:Set("!_QuestItem", _G[name])
	end
	if(rewardsFrame:GetName() == 'MapQuestInfoRewardsFrame') then
		SV.API:Set("!_QuestItem", rewardsFrame.XPFrame)
		SV.API:Set("!_QuestItem", rewardsFrame.SpellFrame)
		SV.API:Set("!_QuestItem", rewardsFrame.MoneyFrame)
		SV.API:Set("!_QuestItem", rewardsFrame.SkillPointFrame)
		SV.API:Set("!_QuestItem", rewardsFrame.PlayerTitleFrame)
	end
end

local Hook_QuestLogFrame_SetTitleTextColor = function(fontString)
	fontString:SetTextColor(1,1,1,1)
end

local Hook_QuestInfoItem_OnClick = function(self)
	_G.QuestInfoItemHighlight:ClearAllPoints()
	_G.QuestInfoItemHighlight:SetAllPoints(self)
	_G.QuestInfoItemHighlight:Show()
end

local Hook_QuestNPCModel = function(self, _, _, _, _, x, y)
	_G.QuestNPCModel:ClearAllPoints()
	_G.QuestNPCModel:SetPoint("TOPLEFT", self, "TOPRIGHT", x + 18, y)
	QuestNPCModelTextFrame.SetParent(QuestNPCModel)
end

local _hook_DetailScrollShow = function(self)
	if not self.Panel then
		SV.API:Set("Frame", self)
		QuestScrollHelper(self, 509, 630, false)
	end
	self.spellTex:SetHeight(self:GetHeight() + 217)
end

local _hook_QuestLogPopupDetailFrameShow = function(self)

end
--[[
##########################################################
QUEST MODRS
##########################################################
]]--
local function QuestLogFrameStyle()
	--print('test QuestLogFrameStyle')
	if SV.db.Skins.blizzard.enable ~= true or SV.db.Skins.blizzard.quest ~= true then return end

	SV.API:Set("Window", QuestFrameGreetingPanel)
	SV.API:Set("Window", QuestFrameDetailPanel)

	--SV.API:Set("Window", QuestLogFrame)
	SV.API:Set("Window", QuestFrameRewardPanel)
	--SV.API:Set("Window", QuestFrameProgressPanel)

	SV.API:Set("Button", QuestLogFrameAbandonButton)
	SV.API:Set("Button", QuestFramePushQuestAbandonButton)
	SV.API:Set("Button", QuestFrameExitButton)
	SV.API:Set("Button", QuestFrameCompleteButton)
	SV.API:Set("Button", QuestFrameGoodbyeButton)
	SV.API:Set("ExitButton", QuestFrameExitButton)
	SV.API:Set("Tab", QuestLogExpandButtonFrame)
	SV.API:Set("Button", QuestFrameCompleteQuestButton)
	SV.API:Set("Button", QuestFrameCancelButton)
	SV.API:Set("Button", QuestFrameAcceptButton)
	SV.API:Set("Button", QuestFrameDeclineButton)
	
	
	
	
		SV.NPC:Register(QuestFrameDetailPanel, QuestNpcNameFrameQuestFrameNpcNameText)
	
	--########## Quest Progress ##########
	SV.API:Set("Window", QuestLogFrame, true, true)

		
		QuestFrameProgressPanel:RemoveTextures(true)
		QuestFrameProgressPanel:SetStyle("Frame", "Window")
		QuestProgressScrollFrame:RemoveTextures(true)
		QuestProgressScrollFrame:SetStyle("Frame", "Window")

		QuestProgressScrollChildFrame:RemoveTextures(true)
		QuestProgressScrollFrameScrollBar:RemoveTextures()

		QuestProgressText:SetTextColor(1, 1, 1)
		hooksecurefunc(QuestProgressText, "SetTextColor", function(q, k, l, m)
			if k ~= 1 or l ~= 1 or m ~= 1 then
				QuestProgressText:SetTextColor(1, 1, 1)
			end
		end)
		QuestProgressScrollChildFrame:SetStyle("Frame", "Transparent")

		SV.API:Set("ScrollBar", QuestProgressScrollChildFrameScrollBar)

		SV.API:Set("ScrollBar", QuestProgressScrollFrame)

		QuestLogFrame:SetStyle("Frame", "Window")
		QuestProgressScrollFrameScrollBar:SetStyle("!_Frame", "Inset", true)
		QuestProgressScrollFrame.spellTex = QuestProgressScrollFrame:CreateTexture(nil, "ARTWORK")
		QuestProgressScrollFrame.spellTex:SetTexture([[Interface\QuestFrame\QuestBG]])
		QuestProgressScrollFrame.spellTex:SetPoint("TOPLEFT", 0, 0)
		QuestProgressScrollFrame.spellTex:SetSize(512, 512)
		QuestProgressScrollFrame.spellTex:SetTexCoord(0, 1, 0.02, 1)
		_G["QuestFramePortrait"]:Die()

	SV.NPC:Register(QuestFrameProgressPanel, QuestNpcNameFrameQuestFrameNpcNameText)
	
	
	----##########End Quest Progress #######################
	--########## Quest Frame Rewards Panel ##########
	SV.API:Set("Window", QuestLogFrame, true, true)

		
		QuestFrameRewardPanel:RemoveTextures(true)
		QuestFrameRewardPanel:SetStyle("Frame", "Window")
		QuestRewardScrollFrame:RemoveTextures(true)
		QuestRewardScrollFrame:SetStyle("Frame", "Window")

		QuestRewardScrollChildFrame:RemoveTextures(true)
		QuestRewardScrollFrameScrollBar:RemoveTextures()

		QuestInfoRewardText:SetTextColor(1, 1, 1)
		hooksecurefunc(QuestInfoRewardText, "SetTextColor", function(q, k, l, m)
			if k ~= 1 or l ~= 1 or m ~= 1 then
				QuestInfoRewardText:SetTextColor(1, 1, 1)
			end
		end)
		QuestRewardScrollChildFrame:SetStyle("Frame", "Transparent")

		SV.API:Set("ScrollBar", QuestRewardScrollChildFrameScrollBar)

		SV.API:Set("ScrollBar", QuestRewardScrollFrame)

		QuestLogFrame:SetStyle("Frame", "Window")
		QuestRewardScrollFrameScrollBar:SetStyle("!_Frame", "Inset", true)
		QuestRewardScrollFrame.spellTex = QuestRewardScrollFrame:CreateTexture(nil, "ARTWORK")
		QuestRewardScrollFrame.spellTex:SetTexture("")
		QuestRewardScrollFrame.spellTex:SetPoint("TOPLEFT", 0, 0)
		QuestRewardScrollFrame.spellTex:SetSize(100, 100)
		QuestRewardScrollFrame.spellTex:SetTexCoord(0, 1, 0.02, 1)
		--_G["QuestFramePortrait"]:Die()

	SV.NPC:Register(QuestFrameRewardPanel, QuestNpcNameFrameQuestFrameNpcNameText)
	

	
	
	----##########End Quest Progress #######################
	--########## Quest Greeting Scroll Frame ##########
	--SV.API:Set("Window", QuestFrameGreetingPanel, true, true)
	
	--QuestTitleButton1:SetTextColor(1, 1, 1)
	
		
		-- QuestFrameGreetingPanel:RemoveTextures(true)
		-- QuestFrameGreetingPanel:SetStyle("Frame", "Window")
		 QuestGreetingScrollFrame:RemoveTextures(true)
		 QuestGreetingScrollFrame:SetStyle("Frame", "Window")

		-- QuestGreetingScrollChildFrame:RemoveTextures(true)
		-- QuestGreetingScrollChildFrame:RemoveTextures()

		GreetingText:SetTextColor(1, 1, 1)
		hooksecurefunc(GreetingText, "SetTextColor", function(q, k, l, m)
			if k ~= 1 or l ~= 1 or m ~= 1 then
				GreetingText:SetTextColor(1, 1, 1)
			end
		end)
		--QuestGreetingScrollChildFrame:SetStyle("Frame", "Transparent")

		--SV.API:Set("ScrollBar", QuestGreetingScrollChildFrame)

		--SV.API:Set("ScrollBar", QuestGreetingScrollFrame)

		--QuestFrameGreetingPanel:SetStyle("Frame", "Window")
		--QuestGreetingScrollFrameScrollBar:SetStyle("!_Frame", "Inset", true)
		QuestGreetingScrollFrame.spellTex = QuestGreetingScrollFrame:CreateTexture(nil, "ARTWORK")
		QuestGreetingScrollFrame.spellTex:Hide()
	--	QuestGreetingScrollFrame.spellTex:SetPoint("TOPLEFT", 0, 0)
	--	QuestGreetingScrollFrame.spellTex:SetSize(1, 01)
	--	QuestGreetingScrollFrame.spellTex:SetTexCoord(0, 1, 0.02, 1)
		
		--_G["QuestFramePortrait"]:Die()

	--SV.NPC:Register(QuestFrameGreetingPanel, QuestNpcNameFrameQuestFrameNpcNameText)
	

	
	
	----##########End Quest Progress #######################
	
	
	
	
	QuestInfoRewardText:SetTextColor(1,1,1,1)
	QuestInfoTitleHeader:SetTextColor(0.95,0.95,0.15,0.75)
	
	QuestInfoDescriptionText:SetTextColor(1,1,1,1)
	QuestInfoObjectivesHeader:SetTextColor(0.95,0.95,0.15,0.75)	
	QuestInfoObjectivesText:SetTextColor(1,1,1,1)
	
	QuestInfoRewardsFrame.Header:SetTextColor(0.95,0.95,0.15,0.75)
	QuestInfoRewardsFrame.ItemChooseText:SetTextColor(1,1,1,1)



	QuestDetailScrollFrameScrollBar:RemoveTextures(true)

	QuestRewardScrollFrameScrollBar:RemoveTextures(true)
	QuestRewardScrollChildFrame:RemoveTextures(true)

	QuestGreetingScrollFrameScrollBar:RemoveTextures(true)

	QuestDetailScrollFrameScrollBar:SetStyle("Frame", "ScrollBar")

	--QuestScrollHelper(QuestGreetingScrollFrame, 506, 615, true)
	QuestGreetingScrollFrameScrollBar:SetStyle("!_Frame")

	QuestInfoItemHighlight:RemoveTextures()
	QuestInfoItemHighlight:SetStyle("Frame", "Icon")
	QuestInfoItemHighlight:SetSize(148, 50)

	QuestLogExpandTabLeft:Hide()
	QuestLogExpandTabMiddle:Hide()


	local choiceBG = QuestInfoItemHighlight:CreateTexture(nil, "BACKGROUND")
	choiceBG:SetAllPoints(QuestInfoItemHighlight)
	choiceBG:SetColorTexture(0.35, 1, 0, 0.35)
	
	--QuestLogDetailScrollChildFrame:Hide()
		local DescriptionTitle,QLO1,QLThis1,QLThis2,QLThis3,QLThis4,QLThis5,QLThis6,QLThis7,QLThis8,QLThis9,QLThis10,QLThis11,QLThis12,QLThis13,QLThis14,QLThis15,QLThis16,QLThis17,QLThis18 = QuestLogDetailScrollChildFrame:GetRegions()
	--local QuestLogDescriptionTitle,QuestLogItemChooseText,QuestLogItemRecieveText,QuestLogObjective1,QuestLogObjective10,QuestLogObjective2,QuestLogObjective3,QuestLogObjective4,QuestLogObjective5,QuestLogObjective6,QuestLogObjective7,QuestLogObjective8,QuestLogObjective9,QuestLogObjectiveText,QuestLogQuestDescription,QuestLogQuestTitle,QuestLogRequiredMoneyText,QuestLogRewardTitle,QuestLogSpellLearnText,QuestLogTimerText = QuestLogDetailScrollChildFrame:GetRegions()
		DescriptionTitle:SetTextColor(0.95,0.95,0.15,0.75)
		QLO1:SetTextColor(1,1,1,1)
		QLThis1:SetTextColor(1,1,1,1)
		QLThis2:SetTextColor(1,1,1,1)
		QLThis3:SetTextColor(1,1,1,1)
		QLThis4:SetTextColor(1,1,1,1)
		QLThis5:SetTextColor(1,1,1,1)
		QLThis6:SetTextColor(1,1,1,1)
		QLThis7:SetTextColor(1,1,1,1)
		QLThis8:SetTextColor(1,1,1,1)
		QLThis9:SetTextColor(1,1,1,1)
		QLThis10:SetTextColor(1,1,1,1)
		QLThis11:SetTextColor(1,1,1,1)
		QLThis12:SetTextColor(1,1,1,1)
		QLThis13:SetTextColor(0.95,0.95,0.15,0.75)
		QLThis14:SetTextColor(1,1,1,1)
		QLThis15:SetTextColor(1,1,1,1)
		QLThis16:SetTextColor(1,1,1,1)
		QLThis17:SetTextColor(1,1,1,1)
		QLThis18:SetTextColor(1,1,1,1)
		
	




	for i = 1, 10 do
		local name = ("QuestInfoRewardsFrameQuestInfoItem%d"):format(i)
		SV.API:Set("!_QuestItem", _G[name])
	end

	for i = 1, 10 do
		local name = ("MapQuestInfoRewardsFrameQuestInfoItem%d"):format(i)
		SV.API:Set("!_QuestItem", _G[name])
	end

	QuestInfoSkillPointFrame:RemoveTextures()
	QuestInfoSkillPointFrame:SetWidth(QuestInfoSkillPointFrame:GetWidth() - 4)

	local curLvl = QuestInfoSkillPointFrame:GetFrameLevel() + 1
	QuestInfoSkillPointFrame:SetFrameLevel(curLvl)
	QuestInfoSkillPointFrame:SetStyle("!_Frame", "Icon")
	QuestInfoSkillPointFrame:SetBackdropColor(1, 1, 0, 0.5)
	QuestInfoSkillPointFrameIconTexture:SetTexCoord(unpack(_G.InkedSV_ICON_COORDS))
	QuestInfoSkillPointFrameIconTexture:SetDrawLayer("OVERLAY")
	QuestInfoSkillPointFrameIconTexture:SetPoint("TOPLEFT", 2, -2)
	QuestInfoSkillPointFrameIconTexture:SetSize(QuestInfoSkillPointFrameIconTexture:GetWidth()-2, QuestInfoSkillPointFrameIconTexture:GetHeight()-2)
	QuestInfoSkillPointFrameCount:SetDrawLayer("OVERLAY")

	hooksecurefunc("QuestInfoItem_OnClick", Hook_QuestInfoItem_OnClick)
	hooksecurefunc("QuestInfo_Display", StyleQuestRewards)

	QuestRewardScrollFrame:HookScript("OnShow", QuestRewardScrollFrame_OnShow)


	SV.API:Set("CloseButton", QuestLogFrameCloseButton, QuestLogFrame.Panel)

	

	--QuestNPCModel:RemoveTextures()
	--QuestNPCModel:SetStyle("Model", "Frame")

	QuestNPCModelTextFrame:RemoveTextures()
	QuestNPCModelTextFrame:SetStyle("Frame", "Default")
	--QuestNPCModelTextFrame.Panel:SetPoint("TOPLEFT", QuestNPCModel.Panel, "BOTTOMLEFT", 0, -2)

	--SV.API:Set("ScrollBar", QuestLogPopupDetailFrameScrollFrame, 5)
	SV.API:Set("ScrollBar", QuestRewardScrollFrame)
	--SV.API:Set("ScrollBar", QuestGreetingScrollFrame)

	--hooksecurefunc("QuestLogFrame_SetTitleTextColor", Hook_QuestLogFrame_SetTitleTextColor)
	--hooksecurefunc("QuestLogFrame_ShowQuestPortrait", Hook_QuestNPCModel)

	SV.NPC:Register(QuestLogFrame, QuestLogFrameNpcNameText)
end

local function QuestChoiceFrameStyle()
	if SV.db.Skins.blizzard.enable ~= true or SV.db.Skins.blizzard.quest ~= true then return end

	SV.API:Set("Window", QuestChoiceFrame, true, true)

	local bgFrameTop = CreateFrame("Frame", nil, QuestChoiceFrame)
	bgFrameTop:SetPoint("TOPLEFT", QuestChoiceFrame, "TOPLEFT", 42, -44)
	bgFrameTop:SetPoint("TOPRIGHT", QuestChoiceFrame, "TOPRIGHT", -42, -44)
	bgFrameTop:SetHeight(85)
	bgFrameTop:SetStyle("Frame", "Lite")
	bgFrameTop:SetPanelColor("highlight")

	local bgFrameBottom = CreateFrame("Frame", nil, QuestChoiceFrame)
	bgFrameBottom:SetPoint("TOPLEFT", QuestChoiceFrame, "TOPLEFT", 42, -140)
	bgFrameBottom:SetPoint("BOTTOMRIGHT", QuestChoiceFrame, "BOTTOMRIGHT", -42, 44)
	bgFrameBottom:SetStyle("Frame", "Lite")


	SV.API:Set("CloseButton", QuestChoiceFrame.CloseButton)
	if(QuestChoiceFrame.Option1) then
		SV.API:Set("Button", QuestChoiceFrame.Option1.OptionButton)
	end
	if(QuestChoiceFrame.Option2) then
		SV.API:Set("Button", QuestChoiceFrame.Option2.OptionButton)
	end
	if(QuestChoiceFrame.Option3) then
		SV.API:Set("Button", QuestChoiceFrame.Option3.OptionButton)
	end
end
--[[
##########################################################
MOD LOADING
##########################################################
]]--
MOD:SaveCustomStyle("QUEST", QuestLogFrameStyle)
MOD:SaveBlizzardStyle('Blizzard_QuestChoice', QuestChoiceFrameStyle)
